@@ -149,7 +149,11 @@ def _python_to_dynamodb(value):
         # datetime instances are stored as UTC in the DB itself.
         # (that way, they become sortable)
         # datetime objects without tzinfo are not supported.
-        return value.astimezone(utc_tz).strftime("%Y-%m-%dT%H:%M:%S.%f%z")
+        s = value.astimezone(utc_tz).strftime("%Y-%m-%dT%H:%M:%S.%f%z")
+        # there is not strftime code to output the timezone with the ':' that
+        # is mandated by the W3CDTF format, so here's an ugly hack
+        s = s[:-2] + ':' + s[-2:]
+        return s
 
     if value or value == 0:
         return value
@@ -190,10 +194,12 @@ def _dynamodb_to_python(schema_type, value):
         # Parse TZ-aware isoformat
 
         # strptime doesn't support timezone parsing (%z flag), so we're forcing
-        # the strings in the database to be UTC (+0000) for now.
+        # the strings in the database to be UTC (+00:00) for now.
         # TODO Handle arbitrary timezones (with manual parsing).
+        if value.endswith('Z'):
+            value = value[:-2] + '+00:00'
         return datetime.datetime.strptime(
-            value, "%Y-%m-%dT%H:%M:%S.%f+0000").replace(tzinfo=utc_tz)
+            value, "%Y-%m-%dT%H:%M:%S.%f+00:00").replace(tzinfo=utc_tz)
 
     return schema_type(value)
 
@@ -542,11 +548,11 @@ class DynamoDBModel(object):
         for name in self.__schema__:
             value = getattr(self, name)
             if isinstance(value, (set, frozenset)):
-                out[name] = list(value)
+                out[name] = sorted(value)
             elif isinstance(value, datetime.datetime):
-                # Using strftime instead of the default str() representation
-                # because it outputs the zone as +HH:MM instead of +HHMM
-                out[name] = value.astimezone(utc_tz).strftime("%Y-%m-%dT%H:%M:%S.%f%z")
+                # Using strftime instead of str or isoformat to get the right
+                # separator ('T') and time offset notation (with ':')
+                out[name] = value.astimezone(utc_tz).isoformat()
             else:
                 out[name] = value
         return out
